#
# spec file for package xsupplicant
#
# Copyright (c) 2014 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           xsupplicant
BuildRequires:  bison
BuildRequires:  flex
BuildRequires:  libiw-devel
BuildRequires:  libpcap-devel
BuildRequires:  libtool
BuildRequires:  openssl-devel
Url:            http://www.open1x.org/
Version:        1.2.8
Release:        142.4
Summary:        Free implementation of  IEEE 802.1X protocol
License:        GPL-2.0+ or BSD-4-Clause
Group:          Productivity/Networking/Radius/Clients
Source:         xsupplicant-%{version}.tar.bz2
Patch:          xsupplicant-strncat.patch
Patch1:         xsupplicant-iwlib.patch
Patch2:         xsupplicant.linux-compiler.patch
Patch3:         xsupplicant-1.2.8-shared.patch
Patch4:         xsupplicant-1.2.8-fix-bashisms.patch
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
This software allows a workstation to authenticate with a RADIUS server
using 802.1x and various EAP protocols.  The intended use is for
computers with wireless LAN connections to complete a strong
authentication before joining the network.



Authors:
--------
    Bryan D. Payne <bdpayne@cs.umd.edu>
    Nick L. Petroni Jr. <npetroni@cs.umd.edu>
    Chris Hessing  <Chris.Hessing@utah.edu>
    Terry Simons   <Terry.Simons@utah.edu>

%prep
%setup -q
%patch
%patch1 -p1
%patch2 -p1
%patch3
%patch4 -p1

%build
autoreconf -fiv
%configure --disable-static --with-pic

%install
make CFLAGS="$RPM_OPT_FLAGS" DESTDIR=%{buildroot} install
rm doc/Makefile* doc/*/Makefile* etc/Makefile* 
rm doc/code-design/code-design.tex doc/code-design/current_code_flow.fig
%{__rm} -f %{buildroot}%{_libdir}/*.la

%post -p /sbin/ldconfig

%postun -p /sbin/ldconfig

%files
%defattr(-,root,root)
%{_bindir}/*
%{_sbindir}/*
%{_libdir}/lib*
%{_includedir}/*
%doc AUTHORS COPYING TODO LICENSE README doc etc

%changelog
* Tue Nov 18 2014 Led <ledest@gmail.com>
- fix bashisms in builddocs.sh script
- add patches:
  * xsupplicant-1.2.8-fix-bashisms.patch
* Tue Mar 27 2012 cfarrell@suse.com
- license update: GPL-2.0+ or BSD-4-Clause
  SPDX format (also compliant with Fedora)
* Thu Oct  6 2011 coolo@suse.com
- add libtool as buildrequires
* Fri Dec  4 2009 seife@opensuse.org
- de-fuzz xsupplicant.linux-compiler.patch
* Thu Aug 20 2009 aj@suse.de
- Use libiw-devel instead of wireless-tools for building
* Sun Apr 26 2009 ro@suse.de
- buildfix: never use libdir/* in filelist (breaks with debuginfo)
* Tue Apr 21 2009 crrodriguez@suse.de
- provide only shared libraries
* Mon Sep 15 2008 ro@suse.de
- fix build with current glibc/kernel headers
* Tue Jan 29 2008 aj@suse.de
- Fix rpmlint warnings:
  * Fix build require on libpcap-devel.
  * Remove unneeded files from tarball.
* Thu Aug  9 2007 olh@suse.de
- remove inclusion of linux/compiler.h
* Fri Aug  3 2007 jg@suse.de
- include net/if.h instead of linux/if.h
* Thu Mar 29 2007 rguenther@suse.de
- add bison and flex BuildRequires
* Mon Mar 19 2007 jg@suse.de
- added some includes that wireless.h does not include anymore
* Wed Jan 24 2007 ro@suse.de
- silence a compiler warning in xsupgui.c (strncat)
* Mon Oct  9 2006 jg@suse.de
- update to version 1.2.8, changes (shortened):
  * Fixed a problem that kept wired authentication from working.
  * Fixed an issue that would cause authentication to be slow.
  * Added the ability to associate using methods other than
    'open system'.
  * Fixed possible remote root stack smash (bug 208975)
  * Added interface operational state setting following successful
    or failed authentication.  Using a DHCP client that supports
    this will allow Xsupplicant to notify it that it needs to
    get/renew an address.
  * Fixed some endianness problems with WPA/WPA2 IEs where 16 bit
    values were used.
  * As promised, the madwifi specific driver code is now gone.
    Madwifi users should use the regular wireless extensions calls
    from now on.
  * Added support for TTLS-EAP-MD5
  * Clean up some memory leaks.
  * Clean up some potential buffer overflows.
  * Fixed PEAP so that it handles getting a success inside of the
    TLS tunnel.  PEAP now works correctly with Funk SBR.
  * Fixed a crash under certain circumstances when the SSID name
    was NULL. (Such as non broadcast SSID names with certain drivers.)
  * Changed the core event handling system to make things a little
    faster, and to suck less CPU time.
  * Fixed a bug in WPA/WPA2 that would often cause the 4 way
    handshake to fail.  (Or, when it succeeded, the keys were invalid.)
  * Added status messages so that the user can see that Xsupplicant
    is doing something.
  * Added the ability to associate to WPA/WPA2 networks without
    setting "wpa_pairwise_cipher" or "wpa_group_cipher" settings.
  * Added support for a group cipher type of 0.  This indicates that
    the group cipher should be the same as the pairwise cipher.
  * Added support for large scan results.  (Scan results > 8192 bytes,
    which would be more than 20 SSIDs on most cards.)
  * Fixed setting BSSID and clearing keys on some cards.
  * Numerous fixes and updates to WPA2/IEEE 802.11i code.
  * BSSID is now selected using signal strength/quality information
    returned during a scan.
  * Added option to enable firmware based roaming.  (Current default
    is for firmware to make roaming decisions.  Will probably change
    in the future.)
  * Fixes to EAP-AKA implementation to correctly support resync.
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Tue Nov  8 2005 dmueller@suse.de
- don't build as root
* Thu Oct 13 2005 jg@suse.de
- update to version 1.2.1
* Thu May 12 2005 meissner@suse.de
- use RPM_OPT_FLAGS, fixed 1 byte overflow.
* Thu Nov 11 2004 ro@suse.de
- fixed file list
* Mon Sep  6 2004 jg@suse.de
- update to version 1.0.1
* Fri Feb 27 2004 ro@suse.de
- fix build on lib64 (find openssl and pcap)
* Wed Feb 25 2004 jg@suse.de
- Initial package
